/***
 * Excerpted from "Stripes: and Java Web Development is Fun Again",
 * published by The Pragmatic Bookshelf.
 * Copyrights apply to this code. It may not be used to create training material, 
 * courses, books, articles, and the like. Contact us if you are in doubt.
 * We make no guarantees that this code is fit for any purpose. 
 * Visit http://www.pragmaticprogrammer.com/titles/fdstr for more book information.
***/
package stripesbook.action;

import java.util.Date;
import net.sourceforge.stripes.action.DefaultHandler;
import net.sourceforge.stripes.action.ForwardResolution;
import net.sourceforge.stripes.action.Resolution;
import net.sourceforge.stripes.validation.EmailTypeConverter;
import net.sourceforge.stripes.validation.LocalizableError;
import net.sourceforge.stripes.validation.Validate;
import net.sourceforge.stripes.validation.ValidateNestedProperties;
import net.sourceforge.stripes.validation.ValidationErrors;
import net.sourceforge.stripes.validation.ValidationMethod;
import stripesbook.model.Contact;
import stripesbook.model.Gender;

public class ContactFormActionBean extends ContactBaseActionBean {
    private static final String FORM="/WEB-INF/jsp/parts/contact_form.jsp";

    @DefaultHandler
    public Resolution form() {
        return new ForwardResolution(FORM);
    }
    
    public Resolution save() {
        // save the contact...

    
        Contact contact = getContact();
        contact.setUser(getUser());
        contactDao.save(contact);
        contactDao.commit();

    
        getContext().getResponse().setHeader("X-Stripes-Success","true");
        return new ForwardResolution(ContactListActionBean.class,
            "table");
    }
    
    @ValidateNestedProperties({
        @Validate(field="firstName", maxlength=25),
        @Validate(field="lastName",  minlength=2, maxlength=40),
        @Validate(field="email", required=true, on="save",
            converter=EmailTypeConverter.class),
        @Validate(field="birthDate", expression="${this < today}")
    })
    @Override
    public void setContact(Contact contact) {
        super.setContact(contact);
    }
    @ValidationMethod(on="save")
    public void validateEmailUnique(ValidationErrors errors) {
        String email = getContact().getEmail();
        Contact other = contactDao.findByEmail(email, getUser());
        if (other != null && !other.equals(getContact())) {
            errors.add("contact.email", new LocalizableError(
              getClass().getName()+".contactEmailAlreadyUsed", other));
        }
    }
    public Date getToday() {
        return new Date();
    }
    public Gender[] getGenders() {
        return Gender.values();
    }
}
